.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   installation
   tutorial
   advanced

   reference

   bibliography

* :ref:`genindex`

.. toctree::
   :maxdepth: 2
   :caption: Project Information

   contributing
   history
   authors
   license
